SecFetchDest constructor
const
SecFetchDest()
Default constructor of SecFetchDest to be used in Cors allowed header and expose header parameter.
Implementation
const SecFetchDest();
Default constructor of SecFetchDest to be used in Cors allowed header and expose header parameter.
const SecFetchDest();